import pygame 

class Player():
    def __init__(self, player, x, y):
        self.player = player
        self.rect = pygame.Rect((x, y, 80, 180))
        self.yVel = 0
        self.jump = False
        self.attackType = 0
        self.attacking = False
        self.health = 100
        self.attackCooldown = 60
        self.attackTime = 0
        self.flip = False
        self.hit = False
        self.shooting = False
        self.bullets = []

    def move(self, W, H, screen, target):
        speed = 10
        dx = 0
        dy = 0
        gravity = 2
    
        #Get keypresses
        key = pygame.key.get_pressed()

        if self.player == 1:
            #Movement
            if key[pygame.K_a]:
                dx = -speed
            if key[pygame.K_d]:
                dx = speed
            #jump
            if key[pygame.K_w] and self.jump == False:
                self.yVel = -30
                self.jump = True
            #attack
            if (key[pygame.K_f] or key[pygame.K_e]) and self.attacking == False or key[pygame.K_e] and self.shooting == True:
                self.hit = True
                self.attacking = True
                if key[pygame.K_f]:
                    self.attackTime = 15
                    self.attackType = 1
                elif key[pygame.K_e]:
                    self.attackType = 2
                    self.bullets.append(Bullet(self.rect.right, self.rect.centery))


        if self.player == 2:
            #Movement
            if key[pygame.K_j]:
                dx = -speed
            if key[pygame.K_l]:
                dx = speed
            #jump
            if key[pygame.K_i] and self.jump == False:
                self.yVel = -30
                self.jump = True
            #attack
            if (key[pygame.K_h] or key[pygame.K_u]) and self.attacking == False or key[pygame.K_u] and self.shooting == True:
                self.hit = True
                self.attacking = True
                if key[pygame.K_h]:
                    self.attackTime = 15
                    self.attackType = 1
                if key[pygame.K_u]:
                    self.attackType = 2
                    self.bullets.append(Bullet(self.rect.right, self.rect.centery))
                    

        self.yVel += gravity
        dy += self.yVel

        #attack cooldown
        if self.attackCooldown > 0:
            self.attackCooldown -= 1
        if self.attackCooldown == 0:
            self.attacking = False
            self.attackCooldown = 60
        
        #attack time
        if self.attackTime > 0:
            self.attack(screen, target)
            self.attackTime -= 1
            

        #Screen limits
        if self.rect.right + dx > W:
            dx = W - self.rect.right
        if self.rect.left + dx < 0:
            dx = -self.rect.left
        if self.rect.bottom + dy > H:
            self.yVel = 0
            self.jump = False
            dy = H - self.rect.bottom

        #players face each other
        if target.rect.centerx > self.rect.centerx:
            self.flip = False
        else:
            self.flip = True
            
        #Update player position
        self.rect.x += dx
        self.rect.y += dy

        #draw bullets
        for bullet in self.bullets:
            if bullet.x < W and bullet.x > 0:
                bullet.x = bullet.x + bullet.vel - (2*bullet.vel* self.flip)
            else:
                self.bullets.pop(self.bullets.index(bullet))
            bulletRect = pygame.Rect(bullet.x,bullet.y, 20, 10)
            pygame.draw.rect(screen, (255, 0, 0), bulletRect)
            if bulletRect.colliderect(target.rect):
                target.health -= 10
                self.bullets.pop(self.bullets.index(bullet))

    def attack(self, surface, target):
        attackingRect = pygame.Rect(self.rect.centerx - (2 * self.rect.width * self.flip), self.rect.y, self.rect.width * 2, self.rect.height)
        if attackingRect.colliderect(target.rect) and self.hit == True:
            target.health -= 10
            self.hit = False
        
        if self.attackType == 1:
            pygame.draw.rect(surface, (0,255,0), attackingRect)
        elif self.attackType == 2:
            pygame.draw.rect(surface, (0,255,0), attackingRect)

    def draw(self, surface):
        pygame.draw.rect(surface, (255, 0, 0), self.rect)

    
class Bullet(object):
    def __init__(self,x,y):
        self.x = x
        self.y = y
        self.vel = 15
            
class Button():
	def __init__(self, image, pos, text_input, font, base_color, hovering_color):
		self.image = image
		self.x_pos = pos[0]
		self.y_pos = pos[1]
		self.font = font
		self.base_color, self.hovering_color = base_color, hovering_color
		self.text_input = text_input
		self.text = self.font.render(self.text_input, True, self.base_color)
		if self.image is None:
			self.image = self.text
		self.rect = self.image.get_rect(center=(self.x_pos, self.y_pos))
		self.text_rect = self.text.get_rect(center=(self.x_pos, self.y_pos))

	def update(self, screen):
		screen.blit(self.text, self.text_rect)

	def checkForInput(self, position):
		if position[0] in range(self.rect.left, self.rect.right) and position[1] in range(self.rect.top, self.rect.bottom):
			return True
		return False

	def changeColor(self, position):
		if position[0] in range(self.rect.left, self.rect.right) and position[1] in range(self.rect.top, self.rect.bottom):
			self.text = self.font.render(self.text_input, True, self.hovering_color)
		else:
			self.text = self.font.render(self.text_input, True, self.base_color)
                
